@@ -15,7 +15,7 @@
 
 
 test_that("illegal input is caught early", {
-  expect_warning(try(lgas_ng("Saarland"), silent = TRUE))    # Deprecation!
+  expect_error(lgas_ng("Saarland"))
   expect_error(lgas_ng("Maryland"),
                "One or more elements of 'ng.state' is not a State in Nigeria",
                fixed = TRUE)
